def get_surface(n=1, m=1):
    """
    Create a surface configuration. 'n' is the number of repetitions
    of the 2-atom (100) unit cell to create the electrode, while 'm'
    is the number of repetitions used for the central region. Only
    integer number of surface layers are possible.
    """
    # BULK
    # Set up lattice
    vector_a = [2.93319206545, 0.0, 0.0]*Angstrom
    vector_b = [0.0, 2.93319206545, 0.0]*Angstrom
    vector_c = [0.0, 0.0, 4.14816]*Angstrom
    lattice = UnitCell(vector_a, vector_b, vector_c)

    # Define elements
    elements = [Silver, Silver]

    # Define coordinates
    fractional_coordinates = [[ 0.5,  0.5,  0.25],
                              [ 0. ,  0. ,  0.75 ]]

    # Set up configuration
    bulk_configuration = BulkConfiguration(
        bravais_lattice=lattice,
        elements=elements,
        fractional_coordinates=fractional_coordinates
        )

    # ELECTRODE
    electrode = bulk_configuration.repeat(1,1,n)

    # CENTRAL REGION
    central = bulk_configuration.repeat(1,1,m)
    vecs = central.primitiveVectors()
    vecs[2,2] += 10*Angstrom
    central.setPrimitiveVectors(vecs[0], vecs[1], vecs[2])

    # 1 ghost atom.
    central._AtomicConfiguration__ghost_atoms = [len(central)-2, len(central)-1]

    # SURFACE
    surface = SurfaceConfiguration(central, electrode)
    return surface

for m in [2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,20]:
    nc = 'Ag100_surface_%i.nc' % m

    # -------------------------------------------------------------
    # Surface Configuration
    # -------------------------------------------------------------
    surface_configuration = get_surface(1, m)

    # -------------------------------------------------------------
    # Calculator
    # -------------------------------------------------------------
    #----------------------------------------
    # Basis Set
    #----------------------------------------
    basis_set = [
        LDABasis.Silver_SingleZetaPolarized,
        ]

    #----------------------------------------
    # Numerical Accuracy Settings
    #----------------------------------------
    left_electrode_k_point_sampling = MonkhorstPackGrid(
        na=9,
        nb=9,
        nc=100,
        )
    left_electrode_numerical_accuracy_parameters = NumericalAccuracyParameters(
        k_point_sampling=left_electrode_k_point_sampling,
        )

    device_k_point_sampling = MonkhorstPackGrid(
        na=9,
        nb=9,
        nc=100,
        )
    device_numerical_accuracy_parameters = NumericalAccuracyParameters(
        k_point_sampling=device_k_point_sampling,
        )

    #----------------------------------------
    # Poisson Solver Settings
    #----------------------------------------
    left_electrode_poisson_solver = FastFourier2DSolver(
        boundary_conditions=[[PeriodicBoundaryCondition(),PeriodicBoundaryCondition()],
                             [PeriodicBoundaryCondition(),PeriodicBoundaryCondition()],
                             [PeriodicBoundaryCondition(),PeriodicBoundaryCondition()]]
        )

    device_poisson_solver = FastFourier2DSolver(
        boundary_conditions=[[PeriodicBoundaryCondition(),PeriodicBoundaryCondition()],
                             [PeriodicBoundaryCondition(),PeriodicBoundaryCondition()],
                             [DirichletBoundaryCondition(),NeumannBoundaryCondition()]]
        )

    #----------------------------------------
    # Electrode Calculators
    #----------------------------------------
    left_electrode_calculator = LCAOCalculator(
        basis_set=basis_set,
        numerical_accuracy_parameters=left_electrode_numerical_accuracy_parameters,
        poisson_solver=left_electrode_poisson_solver,
        )

    right_electrode_calculator = LCAOCalculator()

    #----------------------------------------
    # Device Calculator
    #----------------------------------------
    calculator = DeviceLCAOCalculator(
        basis_set=basis_set,
        numerical_accuracy_parameters=device_numerical_accuracy_parameters,
        poisson_solver=device_poisson_solver,
        electrode_calculators=
            [left_electrode_calculator, right_electrode_calculator],
        )

    surface_configuration.setCalculator(calculator)
    nlprint(surface_configuration)
    surface_configuration.update()
    nlsave(nc, surface_configuration)

    # -------------------------------------------------------------
    # Chemical Potential
    # -------------------------------------------------------------
    chemical_potential = ChemicalPotential(surface_configuration)
    nlsave(nc, chemical_potential)
    nlprint(chemical_potential)

    # -------------------------------------------------------------
    # Electrostatic Difference Potential
    # -------------------------------------------------------------
    electrostatic_difference_potential = ElectrostaticDifferencePotential(surface_configuration)
    nlsave(nc, electrostatic_difference_potential)
